@@ -12,7 +12,7 @@ from functools import partial
 from .. import core
 from ..consts import CONFIG
 from ..consts import RAPPORT_HTML
-from ..consts import REST_CLIENT
+# from ..consts import REST_CLIENT
 from ..consts import FUPDB_CREDENTIALS
 from ..consts import LOGS
 from ..customer import Customer
@@ -180,67 +180,72 @@ def notify_try(start_date, stop_date):
 @click.option('--product', is_flag=True, default=False)
 def reconciled(product):
     LOGS.logger.info(
-        "FUP/DEFUP reconciliation START. Product={}"
+        "FUP reconciliation START."
         .format(product)
     )
+    # compare fuped customers in aiguillier and fup-services databases
     if not product:
-        """compare les clients fupe dans aiguillier et api-fup"""
-        subject = '[blueline] Reconcile FUP'
+        fuped_aiguiller = core.get_fuped_aiguiller()
+        customers_aiguiller = [customer['name'] for customer in
+                               fuped_aiguiller]
+        customers_si = core.get_customers_si()
+
+        common_customers = set(customers_aiguiller) & set(customers_si)
+        unfuped = [
+            customer for customer in customers_si
+            if customer not in common_customers
+        ]
+        # fuped aiguiller, fuped si
+        fup_success = []
+        fup_success_name = []
+
+        # fuped aiguiller, NOT fuped si
+        fup_error = []
+        fup_error_name = []
+
+        for customer_name in common_customers:
+            fup_history = core.get_last_history(customer_name)
+            if fup_history[0]['status']:
+                fup_success.append(fup_history)
+                fup_success_name.append(customer_name)
+            else:
+                fup_error.append(fup_history)
+                fup_error_name.append(customer_name)
+
+        # build the report
         dataset_reconcile = tablib.Dataset()
-        message = ''
-        customers = []
         dataset_reconcile.headers = [
             'customers',
             'fup_aiguillier',
             'fup_api'
-            ]
+        ]
 
-        response = REST_CLIENT.get(
-            '/fup',
-            auth=(
-                CONFIG['AIGUILLIER']['username'],
-                CONFIG['AIGUILLIER']['password']
-                )
-            )
-        LOGS.logger.info(
-            "Get fup-ed customers in Aiguiller: {}".format(response)
-        )
-        infos = response['content']['fup']
-        infos_aiguillier = [
-                                info['name'].lower()
-                                for info in infos
-                                if info['name']
-                                ]
-        url = core.database_url(**FUPDB_CREDENTIALS)
-        with records.Database(url) as db:
-            sql = (
-                "SELECT * FROM fup AS data "
-                "WHERE datetime = "
-                "(SELECT MAX(datetime) FROM fup "
-                "WHERE customer = data.customer) "
-                "and status = True"
-                )
-            rows = db.query(sql)
-            infos_api = [row.customer for row in rows]
-        customers = [x for x in infos_aiguillier if x not in customers]
-        for info in infos_api:
-            if info not in customers:
-                customers.append(info)
-        for customer in customers:
-            result_aiguillier = 'NO'
-            result_api = 'NO'
-            if customer in infos_aiguillier:
-                result_aiguillier = 'YES'
-            if customer in infos_api:
-                result_api = 'YES'
-            dataset_reconcile.append(
-                [
-                    customer,
-                    result_aiguillier,
-                    result_api
-                    ]
-                )
-        message += str(dataset_reconcile)
+        for customer in fup_success_name:
+            dataset_reconcile.append([
+                customer,
+                "YES",
+                "YES"
+            ])
+
+        for customer in fup_error_name:
+            dataset_reconcile.append([
+                customer,
+                "YES",
+                "NO"
+            ])
+
+        for customer in unfuped:
+            dataset_reconcile.append([
+                customer,
+                "NO",
+                "NO"
+            ])
+
+        if fup_error:
+            core.send_error_report("reconciliation", fup_error)
+
+        message = str(dataset_reconcile)
+        subject = "[blueline] Reconcile FUP"
     else:
         bool_error = False
         dataset_reconcile = tablib.Dataset()
@@ -342,10 +347,21 @@ def reconciled(product):
         else:
             subject = '[blueline] Succes Reconciliation customer'
             message += "Succes"
+
+    # stores the reconciliation values in a csv
     with open('/tmp/details_reconciliation.csv', 'w') as f:
         content = dataset_reconcile.export('csv', delimiter=';')
         f.write(content)
-    # envoyer msg
+
+    # TODO: send report email through generic function
+    # core.send_reconciliation_report(
+    #     destinations=CONFIG['ALERT']['to_1'],
+    #     subject=subject,
+    #     message=message,
+    #     attachment=
+    # )
+
+    # sends the report by email
     email = CONFIG['ALERT']['to_1']
     content = MIMEText(message, 'plain', 'utf-8')
     attachment = MIMEBase('text', 'csv')
@@ -368,9 +384,10 @@ def reconciled(product):
         CONFIG['ALERT']['from'],
         email.split(','),
         msg.as_string()
-        )
+    )
     s.quit()
     LOGS.logger.info("Email '{}' sent to {}".format(msg['Subject'], msg['To']))
+    LOGS.logger.info("FUP reconciliation END.")
 
 
 @cmd.command()
