@@ -240,6 +240,15 @@ class Customer(object):
             period,
             msg
             ):
+        """
+        :param method:
+        :param params:
+        :param policy_name:
+        :param db_status:
+        :param conso:
+        :param period: str in ["hp, "hc"]
+        :param msg:
+        """
         api_request = getattr(REST_CLIENT, method)
         try:
             response = api_request(
